summaryrefslogtreecommitdiff
path: root/src/lv2_gui.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lv2_gui.h')
-rw-r--r--src/lv2_gui.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/lv2_gui.h b/src/lv2_gui.h
index 2857445..8ff7bd6 100644
--- a/src/lv2_gui.h
+++ b/src/lv2_gui.h
@@ -8,33 +8,33 @@
****************************************************************************/
/*
- * This file is part of DrumGizmo.
+ * This file is part of CamSync.
*
* DrumGizmo is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* DrumGizmo is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with DrumGizmo; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/
-#ifndef __DRUMGIZMO_LV2_GUI_H__
-#define __DRUMGIZMO_LV2_GUI_H__
+#ifndef __CAMSYNC_LV2_GUI_H__
+#define __CAMSYNC_LV2_GUI_H__
#include <lv2/lv2plug.in/ns/lv2core/lv2.h>
#include <lv2/lv2plug.in/ns/ext/data-access/data-access.h>
-#define PLUGIN_INSTANCE_URI "http://drumgizmo.org/ns/drumgizmo-plugin-instance"
+#define PLUGIN_INSTANCE_URI "http://camsync.org/ns/camsync-plugin-instance"
-class DrumGizmo;
-struct LV2_DrumGizmo_Descriptor {
- DrumGizmo *(*get_pci)(LV2_Handle instance);
+class CamSync;
+struct LV2_CamSync_Descriptor {
+ CamSync *(*get_pci)(LV2_Handle instance);
};
-#endif/*__DRUMGIZMO_LV2_GUI_H__*/
+#endif/*__CAMSYNC_LV2_GUI_H__*/
@@ -8,33 +8,33 @@
*
- * DrumGizmo is free software; you can redistribute it and/or modify
+ * CamSync is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -8,33 +8,33 @@
* (at your option) any later version.
*
- * DrumGizmo is distributed in the hope that it will be useful,
+ * CamSync is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -8,33 +8,33 @@
*
* You should have received a copy of the GNU General Public License
- * along with DrumGizmo; if not, write to the Free Software
+ * along with CamSync; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/